
**********************************************************************************
* US Housing Wealth Effects Project, Carroll, Otsuka and Slacalek
**********************************************************************************

clear
#delimit;

set more off;
global basePath "H:\jslacalek\research\usWealth\COS-WealthEffects\empirical";
global dataPath $basePath\data;  
global logPath $basePath\stata;
global docPath $basePath\docs\tabs;

cd $logPath;
capture log close;
log using $logPath\ushweMain.log, replace;

global startReg "1960q1";	* start of the sample;
global endReg "2004q4";		* end of the sample;
global nwLags "4";			* # of lags for Newey-West std errors;
global nwLagsW "8";			* # of lags for Newey-West std errors in wealth regressions;

global ivsetW "L(2).dwdel";
global ivsetWPlus "L(2).dwdel L(2).MUExp L(2).fedfunds";
global ivsetWSandN "L(2).dwstdel L(2).dwnstdel";
global ivsetWSandNPlus "L(2).dwstdel L(2).dwnstdel L(2).MUExp L(2).fedfunds";

log off;
use $dataPath\usdata02.dta;
gen t =  q(1947q1)+_n-1;
format t %tq;
tsset t;

do transformData;
log on;

**********************************************************************************;
* W Only;
ivreg2 cdel (L.cdel=$ivsetW) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decay=_b[L.cdel];
sca seDecay=_se[L.cdel];
gen dwdel4Geom  = (D.wealth+decay*LD.wealth +(decay^2)*L2D.wealth +(decay^3)*L3D.wealth)/L4.tcons;

gen cw1 = LD.wealth/L4.tcons;
gen cw2 = decay*L2D.wealth/L4.tcons;
gen cw3 = (decay^2)*L3D.wealth/L4.tcons;
gen cw4 = (decay^3)*L4D.wealth/L4.tcons;

* testing the restrictions in dwsdel4GeomSNPlus and dwndel4GeomSNPlus  ;
newey cdel cw1-cw4  if tin($startReg,$endReg), lag($nwLags);	* HAC errors;
test cw1=cw2=cw3=cw4;

reg cdel L.dwdel4Geom if tin($startReg,$endReg);
sca rbarW1=e(r2_a);
newey cdel L.dwdel4Geom if tin($startReg,$endReg), lag($nwLagsW);
sca bW1=_b[L.dwdel4Geom];
sca seW1=_se[L.dwdel4Geom];

durbina ,lag(8) force robust;
sca LRIVW = bW1/(decay*(1-decay));
disp LRIVW;

* W Plus;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decayPlus=_b[L.cdel];
sca seDecayPlus=_se[L.cdel];
gen dwdel4GeomPlus  = (D.wealth+decay*LD.wealth +(decay^2)*L2D.wealth +(decay^3)*L3D.wealth)/L4.tcons;

cap drop cw1-cw4;
gen cw1 = LD.wealth/L4.tcons;
gen cw2 = decayPlus*L2D.wealth/L4.tcons;
gen cw3 = (decayPlus^2)*L3D.wealth/L4.tcons;
gen cw4 = (decayPlus^3)*L4D.wealth/L4.tcons;

* testing the restrictions in dwsdel4GeomSNPlus and dwndel4GeomSNPlus  ;
newey    cdel cw1-cw4  if tin($startReg,$endReg), lag($nwLags);	* HAC errors;
test cw1=cw2=cw3=cw4;

reg cdel L.dwdel4GeomPlus L.MUExp L.fedfund if tin($startReg,$endReg);
sca rbarWPlus=e(r2_a);

newey cdel L.dwdel4GeomPlus L.MUExp L.fedfunds if tin($startReg,$endReg), lag($nwLagsW);
sca bWPlus1=_b[L.dwdel4GeomPlus];
sca seWPlus1=_se[L.dwdel4GeomPlus];
sca bWPlus2=_b[L.MUExp];
sca seWPlus2=_se[L.MUExp];
sca bWPlus3=_b[L.fedfunds];
sca seWPlus3=_se[L.fedfunds];

durbina ,lag(8) force robust;
sca LRIVWPlus = bWPlus1/(decayPlus*(1-decayPlus));
disp LRIVWPlus;

* WSAndWN;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWSandN) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decaySandN=_b[L.cdel];
sca seDecaySandN=_se[L.cdel];

gen dwstdel4GeomSN  = (D.wthstock+decaySandN*LD.wthstock +(decaySandN^2)*L2D.wthstock +(decaySandN^3)*L3D.wthstock)/L4.tcons;
gen dwnstdel4GeomSN  = (D.wthnonstock+decaySandN*LD.wthnonstock +(decaySandN^2)*L2D.wthnonstock + (decaySandN^3)*L3D.wthnonstock)/L4.tcons;

gen cwst1 = LD.wthstock/L4.tcons;
gen cwst2 = decaySandN*L2D.wthstock/L4.tcons;
gen cwst3 = (decaySandN^2)*L3D.wthstock/L4.tcons;
gen cwst4 = (decaySandN^3)*L4D.wthstock/L4.tcons;

gen cwnst1 = LD.wthnonstock/L4.tcons; 
gen cwnst2 = decaySandN*L2D.wthnonstock/L4.tcons;
gen cwnst3 = (decaySandN^2)*L3D.wthnonstock/L4.tcons;
gen cwnst4 = (decaySandN^3)*L4D.wthnonstock/L4.tcons;

* testing the restrictions in dwstdel4GeomSNSandN and dwnstdel4GeomSNSandN  ;
newey    cdel cwst1-cwst4 cwnst1-cwnst4  if tin($startReg,$endReg), lag($nwLags);	* HAC errors;
test cwst1=cwst2=cwst3=cwst4;
test cwnst1=cwnst2=cwnst3=cwnst4;

reg cdel L.dwstdel4GeomSN L.dwnstdel4GeomSN if tin($startReg,$endReg);
sca rbarWSN=e(r2_a);

newey cdel L.dwstdel4GeomSN L.dwnstdel4GeomSN if tin($startReg,$endReg), lag($nwLagsW);
sca bdwstdel4GeomSN=_b[L.dwstdel4GeomSN];
sca sedwstdel4GeomSN=_se[L.dwstdel4GeomSN];
sca bdwnstdel4GeomSN=_b[L.dwnstdel4GeomSN];
sca sedwnstdel4GeomSN=_se[L.dwnstdel4GeomSN];

test L.dwstdel4GeomSN = L.dwnstdel4GeomSN;
sca pvalSN=r(p);
disp pvalSN;

durbina ,lag(8) force robust;
scalar  LRIVST = bdwstdel4GeomSN/(decaySandN*(1-decaySandN));
scalar  LRIVNST = bdwnstdel4GeomSN/(decaySandN*(1-decaySandN));
disp LRIVST;
disp LRIVNST;

* WSAndWNPlus;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decaySandNPlus=_b[L.cdel];
sca seDecaySandNPlus=_se[L.cdel];

gen dwstdel4GeomSNPlus  = (D.wthstock+decaySandNPlus*LD.wthstock +(decaySandNPlus^2)*L2D.wthstock +(decaySandNPlus^3)*L3D.wthstock)/L4.tcons;
gen dwnstdel4GeomSNPlus  = (D.wthnonstock+decaySandNPlus*LD.wthnonstock +(decaySandNPlus^2)*L2D.wthnonstock + (decaySandNPlus^3)*L3D.wthnonstock)/L4.tcons;

cap drop cwnst1-cwnst4 cwst1-cwst4;

gen cwst1 = LD.wthstock/L4.tcons;
gen cwst2 = decaySandNPlus*L2D.wthstock/L4.tcons;
gen cwst3 = (decaySandNPlus^2)*L3D.wthstock/L4.tcons; 
gen cwst4 = (decaySandNPlus^3)*L4D.wthstock/L4.tcons;

gen cwnst1 = LD.wthnonstock/L4.tcons; 
gen cwnst2 = decaySandNPlus*L2D.wthnonstock; 
gen cwnst3 = (decaySandNPlus^2)*L3D.wthnonstock; 
gen cwnst4 = (decaySandNPlus^3)*L4D.wthnonstock; 

* testing the restrictions in dwstdel4GeomSNSandNPlus and dwnstdel4GeomSNSandNPlus  ;
newey cdel cwst1-cwst4 cwnst1-cwnst4  if tin($startReg,$endReg), lag($nwLags);	* HAC errors;
test cwst1=cwst2=cwst3=cwst4;
test cwnst1=cwnst2=cwnst3=cwnst4;

reg cdel L.dwstdel4GeomSNPlus L.dwnstdel4GeomSNPlus L.MUExp L.fedfunds if tin($startReg,$endReg);
sca rbarWSNPlus=e(r2_a);

newey cdel L.dwstdel4GeomSNPlus L.dwnstdel4GeomSNPlus L.MUExp L.fedfunds if tin($startReg,$endReg), lag($nwLagsW);
sca bdwstdel4GeomSNPlus=_b[L.dwstdel4GeomSNPlus];
sca sedwstdel4GeomSNPlus=_se[L.dwstdel4GeomSNPlus];
sca bdwnstdel4GeomSNPlus=_b[L.dwnstdel4GeomSNPlus];
sca sedwnstdel4GeomSNPlus=_se[L.dwnstdel4GeomSNPlus];
sca bSNPlusMich=_b[L.MUExp];
sca seSNPlusMich=_se[L.MUExp];
sca bSNPlusFF=_b[L.fedfunds];
sca seSNPlusFF=_se[L.fedfunds];

test L.dwstdel4GeomSNPlus = L.dwnstdel4GeomSNPlus;
sca pvalSNPlus=r(p);
disp pvalSNPlus;

durbina ,lag(8) force robust;
scalar  LRIVSTPlus = bdwstdel4GeomSNPlus/(decaySandNPlus*(1-decaySandNPlus));
scalar  LRIVNSTPlus = bdwnstdel4GeomSNPlus/(decaySandNPlus*(1-decaySandNPlus));
disp LRIVSTPlus;
disp LRIVNSTPlus;

log off;
* Tables;
**********************************************************************************;
mat tableSR =(
bW1,.,.,.,.,.,rbarW1\
seW1,.,.,.,.,.,.\
bWPlus1,.,.,bWPlus2,bWPlus3,.,rbarWPlus\
seWPlus1,.,.,seWPlus2,seWPlus3,.,.\
.,bdwstdel4GeomSN,bdwnstdel4GeomSN,.,.,pvalSN,rbarWSN\
.,sedwstdel4GeomSN,sedwnstdel4GeomSN,.,.,.,.\
.,bdwstdel4GeomSNPlus,bdwnstdel4GeomSNPlus,bSNPlusMich,bSNPlusFF,pvalSNPlus,rbarWSNPlus\
.,sedwstdel4GeomSNPlus,sedwnstdel4GeomSNPlus,seSNPlusMich,seSNPlusFF,.,.
);

mat colnames tableSR = dW dWS dWN MU FF Test barR2;
mat rownames tableSR = W - Wplus - WNS - WNSplus -;

mat tableLR =(
decay,LRIVW,.,.\
seDecay,.,.,.\
decayPlus,LRIVWPlus,.,.\
seDecayPlus,.,.,.\
decaySandN,.,LRIVST,LRIVNST\
seDecaySandN,.,.,.\
decaySandNPlus,.,LRIVSTPlus,LRIVNSTPlus\
seDecaySandNPlus,.,.,.
);

mat colnames tableLR = rho W WST WNST;
mat rownames tableLR = W - Wplus - WNST - WNSTplus -;

* Print Tables;
**********************************************************************************;
do writeSRmat;
do writeLRmat;

log on;
**********************************************************************************;
disp labelW;
mat li tableSR, format(%5.4f);
mat li tableLR, format(%5.3f);

log close;	
